@@ -5,11 +5,10 @@ test_that("bind adds boundaries on either end",{
     expected <- c("[A]", "[B]", "[C]", "[D]", "[E]", "[F]", "[G]", "[H]", "[I]", 
         "[J]")
     
-    expect_identical(bind(LETTERS[1:10], "[", "]"), expected)
+    expect_equivalent(bind(LETTERS[1:10], left="[", right="]"), expected)
 
 })
 
 
 
 
-
