@@ -10,8 +10,8 @@ test_that("rm_between is removing and extracting betweened text single markers",
     
     x3 <- list(NA_character_, "running")
 	
-    expect_true(identical(rm_between(x, "@a", "@b"), x2))
-    expect_true(identical(rm_between(x, "@a", "@b", extract=TRUE), x3))
+    expect_equivalent(rm_between(x, "@a", "@b"), x2)
+    expect_equivalent(rm_between(x, "@a", "@b", extract=TRUE), x3)
 
 })
 
@@ -25,8 +25,8 @@ test_that("rm_between is removing betweened text multiple markers",{
 	
     z2 <- c("Where is the ?", "I think he's with .")
 
-	expect_true(identical(rm_between(x, c("/", "@a"), c("#", "@b")), z2))
-    expect_true(identical(rm_between(y, c("L1", 98), c("L2", 99)), z2))
+	expect_equivalent(rm_between(x, c("/", "@a"), c("#", "@b")), z2)
+    expect_equivalent(rm_between(y, c("L1", 98), c("L2", 99)), z2)
 	
 })
 
@@ -41,8 +41,7 @@ test_that("rm_between is extracting betweened text multiple markers",{
 
 	z3 <- list("big dog", c("running", "little cat"))
 
-	expect_true(identical(rm_between(x, c("/", "@a"), c("#", "@b"), extract=TRUE), z3))
-    expect_true(identical(rm_between(y, c("L1", 98), c("L2", 99), extract=TRUE), z3))
+	expect_equivalent(rm_between(x, c("/", "@a"), c("#", "@b"), extract=TRUE), z3)
+    expect_equivalent(rm_between(y, c("L1", 98), c("L2", 99), extract=TRUE), z3)
 		
 })
-
