@@ -8,7 +8,7 @@ test_that("rm_endmark is removing/replacing emoticon strings",{
 	x2 <- c("I like the dog", "I want it", "I;", "Who is| that", "Hello world", 
 		"You")
 
-    expect_true(identical(rm_endmark(x), x2))
+    expect_equivalent(rm_endmark(x), x2)
 
 })
 
@@ -20,8 +20,7 @@ test_that("rm_endmark is extracting emoticon strings",{
 
     x3 <- list(".", "*|", NA_character_, "?", NA_character_, "...")
 
-    expect_true(identical(rm_endmark(x, extract=TRUE), x3))
+    expect_equivalent(rm_endmark(x, extract=TRUE), x3)
 })
 
 
-
