@@ -8,7 +8,7 @@ test_that("rm_percent is removing/replacing percent strings",{
     x2 <- c("There is $5.50 for me.", "that's of the pizza", "is $26 or $25.99"
         )
 
-    expect_true(identical(rm_percent(x), x2))	
+    expect_equivalent(rm_percent(x), x2)	
 	
 })
 
@@ -20,8 +20,7 @@ test_that("rm_percent is extracting percent strings",{
 	
     x3 <- list(NA_character_, "45.6%", "14%")
 
-    expect_true(identical(rm_percent(x, extract=TRUE), x3))
+    expect_equivalent(rm_percent(x, extract=TRUE), x3)
 })
 
 
-
